.. ROIextract documentation master file, created by
   sphinx-quickstart on Fri Mar 22 22:56:38 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ROIextract's documentation!
======================================

**ROIextract** is a Python library for extraction of time series of MEG or EEG activity from regions of interest.
The main focus is on using the *cross-talk function* for quantifying, visualizing and optimizing the remaining field spread.
Check out the :doc:`usage` section for further information, including how to :ref:`install <installation>` the project.

.. note::

   This project is under active development, current API may still change.

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Contents
--------

.. toctree::

   usage
   api
